<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="2.0" language="es" sourcelanguage="">
<context encoding="UTF-8">
    <name>Dialog</name>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Préférences de pyMecaVideo</source>
        <translation type="obsolete">Preferencias de pyMecaVideo</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Échelle des vitesses (px pour 1m/s)</source>
        <translation type="obsolete">Escala de velocidades (px para 1m/s)</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Vitesses affichées</source>
        <translation type="obsolete">Velocidades mostradas</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Afficheur vidéo</source>
        <translation type="obsolete">Display video</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Niveau de verbosité (débogage)</source>
        <translation type="obsolete">Nivel de debug</translation>
    </message>
</context>
<context>
    <name>Label_Echelle</name>
    <message>
        <location filename="." line="144"/>
        <source>Choisir le nombre de points puis &quot;D&#xc3;&#xa9;marrer l&apos;acquisition&quot; </source>
        <translation type="obsolete">Escojer el número de puntos y &quot;iniciar la acquisición&quot;</translation>
    </message>
</context>
<context>
    <name>StartQT4</name>
    <message>
        <location filename="pymecavideo.py" line="379"/>
        <source>ind&#xc3;&#xa9;f.</source>
        <translation type="obsolete">indéf.</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>chemin vers les modules : %s</source>
        <translation type="obsolete">Carpeta de los Módulos</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1041"/>
        <source>temps en seconde, positions en m&#xc3;&#xa8;tre</source>
        <translation type="obsolete">tiempo en segundos, posición en metros</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>point N&#xc2;&#xb0; </source>
        <translation type="obsolete">Point N° </translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Cliquer sur le point N&#xc2;&#xb0;%d</source>
        <translation type="obsolete">Clic en el punto N° :</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1518"/>
        <source>D&#xc3;&#xa9;finir une &#xc3;&#xa9;chelle</source>
        <translation type="obsolete">Definir la escala</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1518"/>
        <source>Quelle est la longueur en m&#xc3;&#xa8;tre de votre &#xc3;&#xa9;talon sur l&apos;image ?</source>
        <translation type="obsolete">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1536"/>
        <source> Merci d&apos;indiquer une &#xc3;&#xa9;chelle valable</source>
        <translation type="obsolete">Usted tiene que dar una escala válida</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1592"/>
        <source>Les donn&#xc3;&#xa9;es seront perdues</source>
        <translation type="obsolete">Los datos serán perdidos</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1592"/>
        <source>Votre travail n&apos;a pas &#xc3;&#xa9;t&#xc3;&#xa9; sauvegard&#xc3;&#xa9;
Voulez-vous les sauvegarder ?</source>
        <translation type="obsolete">Su trabajo no ha sido guardado.
¿Quiere Usted guardarlo ahora?</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1614"/>
        <source>Vous avez atteint le d&#xc3;&#xa9;but de la vid&#xc3;&#xa9;o</source>
        <translation type="obsolete">Usted alcanzó el principio del video</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1650"/>
        <source>Ouvrir une vid&#xc3;&#xa9;o</source>
        <translation type="obsolete">Abrir un video</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1645"/>
        <source>Nom de fichier non conforme</source>
        <translation type="obsolete">Nombre de archivo no valido</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Le nom de votre fichier contient des caract&#xc3;&#xa8;res accentu&#xc3;&#xa9;s ou des espaces.
 Merci de bien vouloir le renommer avant de continuer</source>
        <translation type="obsolete">El nombre de su archivo contiene caracteres con acentos o espacios. Por favor retirenlos antes de seguir.</translation>
    </message>
    <message>
        <location filename="pymecavideo.py" line="1677"/>
        <source>Veuillez choisir une image et d&#xc3;&#xa9;finir l&apos;&#xc3;&#xa9;chelle</source>
        <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>D&#xc3;&#xa9;sol&#xc3;&#xa9; pas de fichier d&apos;aide pour ce langage %s.</source>
        <translation type="obsolete">Lo siento, no hay archivo de ayuda para este idioma</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Impossible de lire %s</source>
        <translation type="obsolete">Imposible de leer %s</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Usage : pymecavideo [-f fichier | --fichier_pymecavideo=fichier]</source>
        <translation type="obsolete">Uso : pymecavideo [-f fichier | --fichier_pymecavideo=fichier]</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>point N&#xc2;&#xb0;</source>
        <translation type="obsolete">punto N°</translation>
    </message>
</context>
<context>
    <name>pymecavideo</name>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="37"/>
        <source>PyMecaVideo, analyse mécanique des vidéos</source>
        <translation type="obsolete">PyMecaVideo, análisis mecánica de los videos</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="86"/>
        <source>Acquisition des données</source>
        <translation type="obsolete">Acquisición de datos</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="189"/>
        <source>Pas de vidéos chargées</source>
        <translation type="obsolete">No se ha cargado ningún video</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Bienvenue sur pymeca vidéo, pas d&apos;images chargée</source>
        <translation type="obsolete">Bienvenidos en pymecavideo, no se ha cargado ningún video</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="551"/>
        <source>Définir l&apos;échelle</source>
        <translation type="obsolete">Definir la escala</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="229"/>
        <source>Image n°</source>
        <translation type="obsolete">Imagen n°</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Nombre de points à étudier</source>
        <translation type="obsolete">Numero de puntos a estudiar</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="345"/>
        <source>indéf.</source>
        <translation>indef.</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="564"/>
        <source>px/m</source>
        <translation type="obsolete">px/m</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Démarrer l&apos;acquisition</source>
        <translation type="obsolete">Iniciar la acquisiciónf</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="535"/>
        <source>Tout réinitialiser</source>
        <translation type="obsolete">Reinicializar a todo</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>efface le point précédent</source>
        <translation type="obsolete">elimina el punto precedente</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="455"/>
        <source>rétablit le point suivant</source>
        <translation type="obsolete">recupera el punto precedente</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>trajectoires et mesures</source>
        <translation type="obsolete">trayectorias y medidas</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Origine du référentiel :</source>
        <translation type="obsolete">Origen del referencial</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Vidéo calculée</source>
        <translation type="obsolete">Video calculado</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>V. normale</source>
        <translation type="obsolete">V. normal</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /2</source>
        <translation type="obsolete">velocidad 1/2</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /4</source>
        <translation type="obsolete">velocidad 1/4</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>ralenti /8</source>
        <translation type="obsolete">velocidad 1/8</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Échelle de vitesses :</source>
        <translation type="obsolete">Escala de velocidades</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="832"/>
        <source>px pour 1 m/s</source>
        <translation type="obsolete">px para 1 m/s</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo_mini.ui" line="972"/>
        <source>Coordonnées</source>
        <translation type="obsolete">Coordenadas</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="984"/>
        <source>Copier les mesures dans le presse papier</source>
        <translation type="obsolete">Copiar medidas </translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Fichier</source>
        <translation type="obsolete">Archivo</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Aide</source>
        <translation type="obsolete">Ayuda</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Édition</source>
        <translation type="obsolete">Edicion</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1894"/>
        <source>Ouvrir une vidéo</source>
        <translation type="unfinished">Abrir un video</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1110"/>
        <source>avanceimage</source>
        <translation type="obsolete">adelanta imagen</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo_mini.ui" line="1115"/>
        <source>reculeimage</source>
        <translation type="obsolete">retraza imagen</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>Quitter</source>
        <translation type="obsolete">Salir</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Enregistrer les données</source>
        <translation type="obsolete">Guardar datos</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>À propos</source>
        <translation type="obsolete">About</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Rouvrir un fichier mecavidéo</source>
        <translation type="obsolete">Reabrir un archivo mecavideo</translation>
    </message>
    <message encoding="UTF-8">
        <location filename="." line="144"/>
        <source>Préférences</source>
        <translation type="obsolete">Preferencias</translation>
    </message>
    <message>
        <location filename="." line="144"/>
        <source>copier dans le presse-papier</source>
        <translation type="obsolete">copiar</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1445"/>
        <source>Choisir ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="271"/>
        <source>ind&#xc3;&#xa9;f</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="883"/>
        <source>Ouvrir un projet Pymecavideo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="883"/>
        <source>fichiers pymecavideo(*.csv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1190"/>
        <source>temps en seconde, positions en m&#xc3;&#xa8;tre</source>
        <translation type="unfinished">tiempo en segundos, posición en metros</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1548"/>
        <source>Vous avez atteint la fin de la vid&#xc3;&#xa9;o</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1754"/>
        <source>D&#xc3;&#xa9;finir une &#xc3;&#xa9;chelle</source>
        <translation type="unfinished">Definir la escala</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1754"/>
        <source>Quelle est la longueur en m&#xc3;&#xa8;tre de votre &#xc3;&#xa9;talon sur l&apos;image ?</source>
        <translation type="unfinished">¿Cuál es el tamaño , en metros de su calibrador en la imagen?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1775"/>
        <source> Merci d&apos;indiquer une &#xc3;&#xa9;chelle valable</source>
        <translation type="unfinished">Usted tiene que dar una escala válida</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1831"/>
        <source>Les donn&#xc3;&#xa9;es seront perdues</source>
        <translation type="unfinished">Los datos serán perdidos</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1831"/>
        <source>Votre travail n&apos;a pas &#xc3;&#xa9;t&#xc3;&#xa9; sauvegard&#xc3;&#xa9;
Voulez-vous les sauvegarder ?</source>
        <translation type="unfinished">Su trabajo no ha sido guardado.
¿Quiere Usted guardarlo ahora?</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1782"/>
        <source>Vous avez atteint le d&#xc3;&#xa9;but de la vid&#xc3;&#xa9;o</source>
        <translation type="obsolete">Usted alcanzó el principio del video</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1889"/>
        <source>Nom de fichier non conforme</source>
        <translation type="unfinished">Nombre de archivo no valido</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1862"/>
        <source>Veuillez choisir une image et d&#xc3;&#xa9;finir l&apos;&#xc3;&#xa9;chelle</source>
        <translation type="obsolete">Usted debe escojer una imagen y definir la escala</translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1875"/>
        <source>fichiers vid&#xc3;&#xa9;os ( *.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.wmv *.mov)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="476"/>
        <source>Enregistrer la chronophotographie</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="476"/>
        <source>fichiers images(*.png *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1283"/>
        <source>Veuillez s&#xc3;&#xa9;lectionner un cadre autour de(s) l&apos;objet(s) que vous voulez suivre.
Vous pouvez arr&#xc3;&#xaa;ter &#xc3;&#xa0; tous moments la capture en appuyant sur le bouton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1889"/>
        <source>Le nom de votre fichier contient des caract&#xc3;&#xa8;res accentu&#xc3;&#xa9;s ou des espaces.
Merci de bien vouloir le renommer avant de continuer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="318"/>
        <source>NON DISPO : {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1261"/>
        <source>point N° {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1476"/>
        <source>Evolution de l&apos;abscisse du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1476"/>
        <source>Evolution de l&apos;ordonnée du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/pymecavideo.py" line="1476"/>
        <source>Evolution de la vitesse du point {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1523"/>
        <source>Pointage des positions : cliquer sur le point N° {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1972"/>
        <source>Désolé pas de fichier d&apos;aide pour le langage {0}.</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1859"/>
        <source>fichiers vidéos (*.avi *.mp4 *.ogv *.mpg *.mpeg *.ogg *.mov *.wmv)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="1937"/>
        <source>Veuillez choisir une image (et définir l&apos;échelle)</source>
        <translation type="unfinished"></translation>
    </message>
    <message encoding="UTF-8">
        <location filename="../../src/pymecavideo.py" line="2027"/>
        <source>Pymecavideo n&apos;arrive pas à lire l&apos;image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>self.app</name>
    <message>
        <location filename="../../src/cadreur.py" line="56"/>
        <source>Presser la touche ESC pour sortir</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="159"/>
        <source>Choisir le nombre de points puis &#xc2;&#xab;&#xc2;&#xa0;D&#xc3;&#xa9;marrer l&apos;acquisition&#xc2;&#xa0;&#xc2;&#xbb; </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/echelle.py" line="164"/>
        <source>Vous pouvez continuer votre acquisition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="48"/>
        <source>Proximite de la souris {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="49"/>
        <source>; derniere video {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/preferences.py" line="50"/>
        <source>; videoDir {0}</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../src/cadreur.py" line="138"/>
        <source>Choisir le ralenti</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
